import os
import platform
import subprocess
import sys

import click
import structlog

log = structlog.get_logger()


def install_ffmpeg():
    if not click.confirm(
        "Do you want to install ffmpeg? It is required for ALE.", default=False
    ):
        log.warn(
            "ffmpeg not installed. Please install it manually or restart ALE. Exiting..."
        )
        sys.exit(0)
    system = platform.system().lower()
    if system == "linux":
        package_manager = (
            "apt-get" if os.path.exists("/etc/apt/sources.list") else "yum"
        )
        command = f"sudo {package_manager} install -y ffmpeg"
    elif system == "darwin":
        command = "brew install ffmpeg"
    else:
        raise Exception(f"Unsupported operating system: {system}")
    try:
        subprocess.check_call(command.split())
        print("ffmpeg has been installed successfully!")
    except subprocess.CalledProcessError as e:
        print(f"An error occurred while installing ffmpeg: {e}")


def check_ffmpeg():
    try:
        subprocess.check_call(["ffmpeg", "-version"], stdout=subprocess.DEVNULL)
    except (subprocess.CalledProcessError, FileNotFoundError):
        log.info("ffmpeg is not installed.")
        install_ffmpeg()
